/*
 * Copyright (c) 2013, Ryo Ichinose
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *    * Redistributions of source code must retain the above copyright 
 *      notice, this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above copyright 
 *      notice, this list of conditions and the following disclaimer in the 
 *      documentation and/or other materials provided with the distribution.
 *    * Neither the name of the auther nor the 
 *      names of its contributors may be used to endorse or promote products 
 *      derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package riolab.sample;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.drawable.Drawable;
import android.view.View;

public class ImageView extends View
{
    private final Paint paint = new Paint();
    private Bitmap bitmap;

    public ImageView(Context context)
    {
	super(context);

	Resources res = context.getResources();
	Drawable drawable = res.getDrawable(R.drawable.wallpaper);

	int w = drawable.getIntrinsicWidth();
	int h = drawable.getIntrinsicHeight();

	// Here, I'm converting drawable into bitmap for sample use, 
	// but it's not necessary as I'm saying at the comment within onDraw().

	bitmap = Bitmap.createBitmap(w, h, Bitmap.Config.ARGB_8888);
	Canvas canvas = new Canvas(bitmap);

	drawable.setBounds(0, 0, w, h);
	drawable.draw(canvas);
    }

    @Override
    public void onDraw(Canvas canvas)
    {
	// This progrem is using Canvas#drawBitmap(),
	// but it's O.K. to use Drawable#draw(Canvas) instead.
	// In that case, make sure to use Drawable#setBounds()
	// to specify the region to be drawn.

	super.onDraw(canvas);
	canvas.drawBitmap(bitmap, 0, 0, paint);
    }
}
